searchNodes=[{"ref":"Crux.Structs.html","title":"Crux.Structs","type":"behaviour","doc":"Provides a unified function to create one or a list of structs, invoking their create/1 function if available."},{"ref":"Crux.Structs.html#c:create/1","title":"Crux.Structs.create/1","type":"callback","doc":"Can be implemented by structs to transform the inital data."},{"ref":"Crux.Structs.html#create/2","title":"Crux.Structs.create/2","type":"function","doc":"Creates a struct or a list of structs invoking their create/1 function if available. Examples # A single member iex&gt; %{ ...&gt; &quot;nick&quot; =&gt; &quot;nick&quot;, ...&gt; &quot;user&quot; =&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;646a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; &quot;roles&quot; =&gt; [&quot;251158405832638465&quot;, &quot;373405430589816834&quot;], ...&gt; &quot;mute&quot; =&gt; false, ...&gt; &quot;deaf&quot; =&gt; false, ...&gt; &quot;joined_at&quot; =&gt; &quot;2016-11-02T00:51:21.342000+00:00&quot; ...&gt; } ...&gt; |&gt; Crux.Structs.create(Crux.Structs.Member) %Crux.Structs.Member{ nick: &quot;nick&quot;, user: 218348062828003328, roles: MapSet.new([251158405832638465, 373405430589816834]), mute: false, deaf: false, joined_at: &quot;2016-11-02T00:51:21.342000+00:00&quot;, guild_id: nil } # A single user iex&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;} ...&gt; |&gt; Crux.Structs.create(Crux.Structs.User) %Crux.Structs.User{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;} # Multiple users iex&gt; [ ...&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; %{&quot;username&quot; =&gt; &quot;Drahcirius&quot;, &quot;discriminator&quot; =&gt; &quot;1336&quot;, &quot;id&quot; =&gt; &quot;130175406673231873&quot;, &quot;avatar&quot; =&gt; &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ...&gt; ] ...&gt; |&gt; Crux.Structs.create(Crux.Structs.User) [ %Crux.Structs.User{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, %Crux.Structs.User{username: &quot;Drahcirius&quot;, discriminator: &quot;1336&quot;, id: 130175406673231873, avatar: &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ] # Does not alter already structs iex&gt; Crux.Structs.create( ...&gt; %Crux.Structs.User{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; Crux.Structs.User ...&gt; ) %Crux.Structs.User{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;} # Fallback iex&gt; Crux.Structs.create(nil, nil) nil"},{"ref":"Crux.Structs.html#c:resolve_id/1","title":"Crux.Structs.resolve_id/1","type":"callback","doc":"Can be implemented by structs to provide a mechanism to resolve their id."},{"ref":"Crux.Structs.html#resolve_id/2","title":"Crux.Structs.resolve_id/2","type":"function","doc":"Resolves the id of a struct invoking their resolve_id/1 function if available. # Struct of the concrete type iex&gt; %Crux.Structs.Webhook{id: 618733351624507394} ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.Webhook) 618733351624507394 # Already snowflake iex&gt; 222089067028807682 ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.Role) 222089067028807682 # Snowflake string iex&gt; &quot;222079895583457280&quot; ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.Channel) 222079895583457280 # nil iex&gt; nil ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.Guild) nil # Inexact type that is a resolvable iex&gt; %Crux.Structs.Member{user: 218348062828003328} ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.User) 218348062828003328 # Incorrect type iex&gt; %Crux.Structs.Role{id: 222079439876390922} ...&gt; |&gt; Crux.Structs.resolve_id(Crux.Structs.Emoji) nil"},{"ref":"Crux.Structs.Attachment.html","title":"Crux.Structs.Attachment","type":"module","doc":"Represents a Discord Attachment Object Height and width are only present for images."},{"ref":"Crux.Structs.Attachment.html#create/1","title":"Crux.Structs.Attachment.create/1","type":"function","doc":"Creates a Crux.Structs.Attachment.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Attachment.html#t:t/0","title":"Crux.Structs.Attachment.t/0","type":"type","doc":""},{"ref":"Crux.Structs.AuditLog.html","title":"Crux.Structs.AuditLog","type":"module","doc":"Represents a Discord Audit Log Object"},{"ref":"Crux.Structs.AuditLog.html#create/1","title":"Crux.Structs.AuditLog.create/1","type":"function","doc":"Creates a Crux.Structs.AuditLog.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.AuditLog.html#t:id_resolvable/0","title":"Crux.Structs.AuditLog.id_resolvable/0","type":"type","doc":"All available types that can be resolved into an audit log id."},{"ref":"Crux.Structs.AuditLog.html#t:t/0","title":"Crux.Structs.AuditLog.t/0","type":"type","doc":""},{"ref":"Crux.Structs.AuditLogChange.html","title":"Crux.Structs.AuditLogChange","type":"module","doc":"Represents a Discord Audit Log Change Object"},{"ref":"Crux.Structs.AuditLogChange.html#create/1","title":"Crux.Structs.AuditLogChange.create/1","type":"function","doc":"Creates a Crux.Structs.AuditLogChange.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.AuditLogChange.html#t:audit_log_change_value/0","title":"Crux.Structs.AuditLogChange.audit_log_change_value/0","type":"type","doc":"Represents a value before or after a change. Note that the Role object returned by Discord in audit logs is a partial role that only contains id and name."},{"ref":"Crux.Structs.AuditLogChange.html#t:t/0","title":"Crux.Structs.AuditLogChange.t/0","type":"type","doc":""},{"ref":"Crux.Structs.AuditLogEntry.html","title":"Crux.Structs.AuditLogEntry","type":"module","doc":"Represents a Discord Audit Log Object"},{"ref":"Crux.Structs.AuditLogEntry.html#create/1","title":"Crux.Structs.AuditLogEntry.create/1","type":"function","doc":"Creates a Crux.Structs.AuditLogEntry.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.AuditLogEntry.html#event_name/1","title":"Crux.Structs.AuditLogEntry.event_name/1","type":"function","doc":"Gets the event name from the action type id"},{"ref":"Crux.Structs.AuditLogEntry.html#events/0","title":"Crux.Structs.AuditLogEntry.events/0","type":"function","doc":"Returns a map of all audit log event names with their id"},{"ref":"Crux.Structs.AuditLogEntry.html#t:event_name/0","title":"Crux.Structs.AuditLogEntry.event_name/0","type":"type","doc":"Union type of audit log event name atoms."},{"ref":"Crux.Structs.AuditLogEntry.html#t:t/0","title":"Crux.Structs.AuditLogEntry.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Channel.html","title":"Crux.Structs.Channel","type":"module","doc":"Represents a Discord Channel Object. List of where every property can be present: PropertyText (0)DM (1)Voice (2)Group (3)Category (4)News (5) application_idnononoyesnono bitratenonoyesnonono guild_idyesnoyesnoyesyes iconnononoyesnono idyesyesyesyesyesyes last_message_idyesyesnoyesnoyes last_pin_timestampyesyesnoyesnoyes nameyesnoyesyesyesyes nsfwyesnonononoyes owner_idnononoyesnono parent_idyesnoyesnonoyes permission_overwritesyesnoyesnoyesyes positionyesnoyesnoyesyes rate_limit_per_useryesnonononono recipientsnoyes(One Element)noyesnono topicyesnoyesnoyesyes type012345 user_limitnonoyesnonono Differences opposed to the Discord API Object: :recipients is a MapSet of user ids"},{"ref":"Crux.Structs.Channel.html#create/1","title":"Crux.Structs.Channel.create/1","type":"function","doc":"Creates a Crux.Structs.Channel.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2"},{"ref":"Crux.Structs.Channel.html#resolve_id/1","title":"Crux.Structs.Channel.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Channel.t/0. Automatically invoked by Crux.Structs.resolve_id/2. iex&gt; %Crux.Structs.Message{channel_id: 222079895583457280} ...&gt; |&gt; Crux.Structs.Channel.resolve_id() 222079895583457280 iex&gt; %Crux.Structs.Channel{id: 222079895583457280} ...&gt; |&gt; Crux.Structs.Channel.resolve_id() 222079895583457280 iex&gt; 222079895583457280 ...&gt; |&gt; Crux.Structs.Channel.resolve_id() 222079895583457280 iex&gt; &quot;222079895583457280&quot; ...&gt; |&gt; Crux.Structs.Channel.resolve_id() 222079895583457280"},{"ref":"Crux.Structs.Channel.html#resolve_position/1","title":"Crux.Structs.Channel.resolve_position/1","type":"function","doc":"Resolves a position_resolvable/0 into a channel position. Examples iex&gt; %Crux.Structs.Channel{id: 222079895583457280, position: 5} ...&gt; |&gt; Crux.Structs.Channel.resolve_position() %{id: 222079895583457280, position: 5} iex&gt; {%Crux.Structs.Channel{id: 222079895583457280}, 5} ...&gt; |&gt; Crux.Structs.Channel.resolve_position() %{id: 222079895583457280, position: 5} iex&gt; {222079895583457280, 5} ...&gt; |&gt; Crux.Structs.Channel.resolve_position() %{id: 222079895583457280, position: 5} iex&gt; %{id: 222079895583457280, position: 5} ...&gt; |&gt; Crux.Structs.Channel.resolve_position() %{id: 222079895583457280, position: 5} iex&gt; {nil, 5} ...&gt; |&gt; Crux.Structs.Channel.resolve_position() nil"},{"ref":"Crux.Structs.Channel.html#to_mention/1","title":"Crux.Structs.Channel.to_mention/1","type":"function","doc":"Converts a Crux.Structs.Channel.t/0 into its discord mention format. Example iex&gt; %Crux.Structs.Channel{id: 316880197314019329} ...&gt; |&gt; Crux.Structs.Channel.to_mention() &quot;&lt;#316880197314019329&gt;&quot;"},{"ref":"Crux.Structs.Channel.html#t:id_resolvable/0","title":"Crux.Structs.Channel.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a channel id."},{"ref":"Crux.Structs.Channel.html#t:position_resolvable/0","title":"Crux.Structs.Channel.position_resolvable/0","type":"type","doc":"All available types that can be resolved into a channel position."},{"ref":"Crux.Structs.Channel.html#t:t/0","title":"Crux.Structs.Channel.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Embed.html","title":"Crux.Structs.Embed","type":"module","doc":"Represents a Discord Embed Object. Every property except type is optional, and thus may have default value."},{"ref":"Crux.Structs.Embed.html#t:t/0","title":"Crux.Structs.Embed.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Emoji.html","title":"Crux.Structs.Emoji","type":"module","doc":"Represents a Discord Emoji Object. Differences opposed to the Discord API Object: :user is just the user id"},{"ref":"Crux.Structs.Emoji.html#create/1","title":"Crux.Structs.Emoji.create/1","type":"function","doc":"Creates a Crux.Structs.Emoji.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Emoji.html#resolve_id/1","title":"Crux.Structs.Emoji.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Emoji.t/0. Automatically invoked by Crux.Structs.resolve_id/2. iex&gt; %Crux.Structs.Emoji{id: 618731477143912448} ...&gt; |&gt; Crux.Structs.Emoji.resolve_id() 618731477143912448 iex&gt; %Crux.Structs.Reaction{emoji: %Crux.Structs.Emoji{id: 618731477143912448}} ...&gt; |&gt; Crux.Structs.Emoji.resolve_id() 618731477143912448 iex&gt; 618731477143912448 ...&gt; |&gt; Crux.Structs.Emoji.resolve_id() 618731477143912448 iex&gt; &quot;618731477143912448&quot; ...&gt; |&gt; Crux.Structs.Emoji.resolve_id() 618731477143912448"},{"ref":"Crux.Structs.Emoji.html#to_identifier/1","title":"Crux.Structs.Emoji.to_identifier/1","type":"function","doc":"Converts an Crux.Structs.Emoji.t/0, a Crux.Structs.Reaction.t/0, or a String.t/0 to its discord identifier format. &gt; This is automatically done if using a appropriate rest function. Examples # A custom emoji iex&gt; %Crux.Structs.Emoji{animated: false, id: 396521773216301056, name: &quot;blobwavereverse&quot;} ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;blobwavereverse:396521773216301056&quot; # A custom animated emoji iex&gt; %Crux.Structs.Emoji{animated: true, id: 396521774466203659, name: &quot;ablobwavereverse&quot;} ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;a:ablobwavereverse:396521774466203659&quot; # A regular emoji iex&gt; %Crux.Structs.Emoji{animated: false, id: nil, name: &quot;👋&quot;} ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;%F0%9F%91%8B&quot; # A reaction struct iex&gt; %Crux.Structs.Reaction{ ...&gt; emoji: %Crux.Structs.Emoji{animated: false, id: 356830260626456586, name: &quot;blobReach&quot;} ...&gt; } ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;blobReach:356830260626456586&quot; # An already encoded identifier iex&gt; &quot;👀&quot; ...&gt; |&gt; URI.encode_www_form() ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;%F0%9F%91%80&quot; # A custom emoji&#39;s identifier iex&gt; &quot;eyesRight:271412698267254784&quot; ...&gt; |&gt; Crux.Structs.Emoji.to_identifier() &quot;eyesRight:271412698267254784&quot;"},{"ref":"Crux.Structs.Emoji.html#t:id_resolvable/0","title":"Crux.Structs.Emoji.id_resolvable/0","type":"type","doc":"All available types that can be resolved into an emoji id."},{"ref":"Crux.Structs.Emoji.html#t:identifier_resolvable/0","title":"Crux.Structs.Emoji.identifier_resolvable/0","type":"type","doc":"All available types that can be resolved into a discord emoji identifier. String.t() stands for an already encoded unicode emoji."},{"ref":"Crux.Structs.Emoji.html#t:t/0","title":"Crux.Structs.Emoji.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Guild.html","title":"Crux.Structs.Guild","type":"module","doc":"Represents a Discord Guild Object. Differences opposed to the Discord API Object: :channels is a MapSet of channel ids :emojis is a MapSet of emoji ids :presences does not exists at all"},{"ref":"Crux.Structs.Guild.html#create/1","title":"Crux.Structs.Guild.create/1","type":"function","doc":"Creates a t:Crux.Structs.Guild/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Guild.html#resolve_id/1","title":"Crux.Structs.Guild.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Guild.t/0. Automatically invoked by Crux.Structs.resolve_id/2. iex&gt; %Crux.Structs.Guild{id: 516569101267894284} ...&gt; |&gt; Crux.Structs.Guild.resolve_id() 516569101267894284 iex&gt; %Crux.Structs.Channel{guild_id: 516569101267894284} ...&gt; |&gt; Crux.Structs.Guild.resolve_id() 516569101267894284 iex&gt; %Crux.Structs.Message{guild_id: 516569101267894284} ...&gt; |&gt; Crux.Structs.Guild.resolve_id() 516569101267894284 iex&gt; 516569101267894284 ...&gt; |&gt; Crux.Structs.Guild.resolve_id() 516569101267894284 iex&gt; &quot;516569101267894284&quot; ...&gt; |&gt; Crux.Structs.Guild.resolve_id() 516569101267894284 # DMs iex&gt; %Crux.Structs.Channel{guild_id: nil} ...&gt; |&gt; Crux.Structs.Guild.resolve_id() nil iex&gt; %Crux.Structs.Message{guild_id: nil} ...&gt; |&gt; Crux.Structs.Guild.resolve_id() nil"},{"ref":"Crux.Structs.Guild.html#t:id_resolvable/0","title":"Crux.Structs.Guild.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a guild id."},{"ref":"Crux.Structs.Guild.html#t:t/0","title":"Crux.Structs.Guild.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Integration.html","title":"Crux.Structs.Integration","type":"module","doc":"Represents a Discord Integration Object."},{"ref":"Crux.Structs.Integration.html#create/1","title":"Crux.Structs.Integration.create/1","type":"function","doc":"Creates a Crux.Structs.Integration.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Integration.html#t:t/0","title":"Crux.Structs.Integration.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Invite.html","title":"Crux.Structs.Invite","type":"module","doc":"Represents a Discord Invite Object List of what property can be present fetched with what function: PropertyRest.get_guild_vanity_invite/1Rest.get_invite/1Rest.create_channel_invite/1Rest.delete_invite/1 Rest.get_channel_invites/1 Rest.get_guild_invites/1 codeyesyesyesyes guildnoif not group dmif not group dmif not group dm channelnoyesyesyes inviternoyesyesyes usesyesnoyesno max_usesnonoyesno max_agenonoyesno temporarynonoyesno created_atnonoyesno revokednononono approximate_presence_countnoyesnono approximate_member_countnoyesnono Notes: :guild only has:verification_level, :features, :name, :splash, :id, and :icon. :channel only has :type, :id and :name. You can, if applicable, fetch the full structs from cache."},{"ref":"Crux.Structs.Invite.html#create/1","title":"Crux.Structs.Invite.create/1","type":"function","doc":"Creates a Crux.Structs.Invite.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Invite.html#t:t/0","title":"Crux.Structs.Invite.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Member.html","title":"Crux.Structs.Member","type":"module","doc":"Represents a Discord Guild Member Object. Differences opposed to the Discord API Object: :user is just the user id"},{"ref":"Crux.Structs.Member.html#create/1","title":"Crux.Structs.Member.create/1","type":"function","doc":"Creates a Crux.Structs.Member.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Member.html#resolve_id/1","title":"Crux.Structs.Member.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Member.t/0. Automatically invoked by Crux.Structs.resolve_id/2. For examples see Crux.Structs.User.resolve_id/1."},{"ref":"Crux.Structs.Member.html#to_mention/1","title":"Crux.Structs.Member.to_mention/1","type":"function","doc":"Converts a Crux.Structs.Member.t/0 into its discord mention format. Examples # Without nickname iex&gt; %Crux.Structs.Member{user: 218348062828003328, nick: nil} ...&gt; |&gt; Crux.Structs.Member.to_mention() &quot;&lt;@218348062828003328&gt;&quot; # With nickname iex&gt; %Crux.Structs.Member{user: 218348062828003328, nick: &quot;weltraum&quot;} ...&gt; |&gt; Crux.Structs.Member.to_mention() &quot;&lt;@!218348062828003328&gt;&quot;"},{"ref":"Crux.Structs.Member.html#t:id_resolvable/0","title":"Crux.Structs.Member.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a user id."},{"ref":"Crux.Structs.Member.html#t:t/0","title":"Crux.Structs.Member.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Message.html","title":"Crux.Structs.Message","type":"module","doc":"Represents a Discord Message Object. Differences opposed to the Discord API Object: :mentions is a MapSet of user ids"},{"ref":"Crux.Structs.Message.html#create/1","title":"Crux.Structs.Message.create/1","type":"function","doc":"Creates a Crux.Structs.Message.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Message.html#t:id_resolvable/0","title":"Crux.Structs.Message.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a message id."},{"ref":"Crux.Structs.Message.html#t:mention_channel/0","title":"Crux.Structs.Message.mention_channel/0","type":"type","doc":""},{"ref":"Crux.Structs.Message.html#t:message_activity/0","title":"Crux.Structs.Message.message_activity/0","type":"type","doc":""},{"ref":"Crux.Structs.Message.html#t:message_application/0","title":"Crux.Structs.Message.message_application/0","type":"type","doc":""},{"ref":"Crux.Structs.Message.html#t:message_reference/0","title":"Crux.Structs.Message.message_reference/0","type":"type","doc":"message_id is nil for the initial message sent when a user starts following a channel. guild_id is only nil for some messages during the initial rollout of this feature."},{"ref":"Crux.Structs.Message.html#t:t/0","title":"Crux.Structs.Message.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Overwrite.html","title":"Crux.Structs.Overwrite","type":"module","doc":"Represents a Discord Overwrite Object."},{"ref":"Crux.Structs.Overwrite.html#create/1","title":"Crux.Structs.Overwrite.create/1","type":"function","doc":"Creates a Crux.Structs.Overwrite.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Overwrite.html#resolve_target/1","title":"Crux.Structs.Overwrite.resolve_target/1","type":"function","doc":"Resolves a target_resolvable/0 into an overwrite target. Note that an id or string of it returns :unknown as type. Examples iex&gt; %Crux.Structs.Overwrite{type: &quot;member&quot;, id: 218348062828003328} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;member&quot;, 218348062828003328} iex&gt; %Crux.Structs.Role{id: 376146940762783746} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;role&quot;, 376146940762783746} iex&gt; %Crux.Structs.User{id: 218348062828003328} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;member&quot;, 218348062828003328} iex&gt; %Crux.Structs.Member{user: 218348062828003328} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;member&quot;, 218348062828003328} iex&gt; %Crux.Structs.Message{author: %Crux.Structs.User{id: 218348062828003328}} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;member&quot;, 218348062828003328} iex&gt; %Crux.Structs.VoiceState{user_id: 218348062828003328} ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {&quot;member&quot;, 218348062828003328} iex&gt; 218348062828003328 ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {:unknown, 218348062828003328} iex&gt; &quot;218348062828003328&quot; ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() {:unknown, 218348062828003328} iex&gt; nil ...&gt; |&gt; Crux.Structs.Overwrite.resolve_target() nil"},{"ref":"Crux.Structs.Overwrite.html#t:t/0","title":"Crux.Structs.Overwrite.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Overwrite.html#t:target_resolvable/0","title":"Crux.Structs.Overwrite.target_resolvable/0","type":"type","doc":"All available types that can be resolved into a target for a permission overwrite"},{"ref":"Crux.Structs.Permissions.html","title":"Crux.Structs.Permissions","type":"module","doc":"Custom non discord api struct to help with working with permissions. For more informations see Discord Docs."},{"ref":"Crux.Structs.Permissions.html#add/2","title":"Crux.Structs.Permissions.add/2","type":"function","doc":"Adds permissions to the base permissions. Examples iex&gt; :administrator ...&gt; |&gt; Crux.Structs.Permissions.add(:manage_guild) %Crux.Structs.Permissions{bitfield: 0x28}"},{"ref":"Crux.Structs.Permissions.html#all/0","title":"Crux.Structs.Permissions.all/0","type":"function","doc":"Returns the integer value of all permissions summed up."},{"ref":"Crux.Structs.Permissions.html#explicit/3","title":"Crux.Structs.Permissions.explicit/3","type":"function","doc":"Resolves permissions for a user in a guild, optionally including channel permission overwrites. Raises when the member is not cached. The administrator flag or being owner implicitly does not grant permissions, see implicit/3."},{"ref":"Crux.Structs.Permissions.html#flags/0","title":"Crux.Structs.Permissions.flags/0","type":"function","doc":"Returns a map of all permissions."},{"ref":"Crux.Structs.Permissions.html#has/2","title":"Crux.Structs.Permissions.has/2","type":"function","doc":"Check whether the second permissions are all present in the first. Examples # Administrator won&#39;t grant any other permissions iex&gt; Crux.Structs.Permissions.has(0x8, Crux.Structs.Permissions.all()) false # Resolving a list of `permissions_name`s iex&gt; Crux.Structs.Permissions.has([:send_messages, :view_channel, :read_message_history], [:send_messages, :view_channel]) true # Resolving different types of `permissions`s iex&gt; Crux.Structs.Permissions.has(:administrator, 0x8) true # In different order iex&gt; Crux.Structs.Permissions.has(0x8, :administrator) true"},{"ref":"Crux.Structs.Permissions.html#implicit/3","title":"Crux.Structs.Permissions.implicit/3","type":"function","doc":"Resolves permissions for a user in a guild, optionally including channel permission overwrites. Raises when the member is not cached. The guild-wide administrator flag or being owner implicitly grants all permissions, see explicit/3."},{"ref":"Crux.Structs.Permissions.html#missing/2","title":"Crux.Structs.Permissions.missing/2","type":"function","doc":"Similar to has/2 but returns a Crux.Structs.Permissions.t/0 of the missing permissions. Examples iex&gt; Crux.Structs.Permissions.missing([:send_messages, :view_channel], [:send_messages, :view_channel, :embed_links]) %Crux.Structs.Permissions{bitfield: 0x4000} # Administrator won&#39;t implicilty grant other permissions iex&gt; Crux.Structs.Permissions.missing([:administrator], [:send_messages]) %Crux.Structs.Permissions{bitfield: 0x800} # Everything set iex&gt; Crux.Structs.Permissions.missing([:kick_members, :ban_members, :view_audit_log], [:kick_members, :ban_members]) %Crux.Structs.Permissions{bitfield: 0} # No permissions iex&gt; Crux.Structs.Permissions.missing([:send_messages, :view_channel], []) %Crux.Structs.Permissions{bitfield: 0}"},{"ref":"Crux.Structs.Permissions.html#names/0","title":"Crux.Structs.Permissions.names/0","type":"function","doc":"Returns a list of all permission keys."},{"ref":"Crux.Structs.Permissions.html#new/1","title":"Crux.Structs.Permissions.new/1","type":"function","doc":"Creates a new Crux.Structs.Permissions.t/0 from a valid resolvable/0."},{"ref":"Crux.Structs.Permissions.html#remove/2","title":"Crux.Structs.Permissions.remove/2","type":"function","doc":"Removes permissions from the base permissions Examples iex&gt; [0x8, 0x10, 0x20] ...&gt; |&gt; Crux.Structs.Permissions.remove([0x10, 0x20]) %Crux.Structs.Permissions{bitfield: 0x8}"},{"ref":"Crux.Structs.Permissions.html#resolve/1","title":"Crux.Structs.Permissions.resolve/1","type":"function","doc":"Resolves a resolvable/0 into a bitfield representing the set permissions. Examples # A single bitflag iex&gt; 0x8 ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0x8 # A single name iex&gt; :administrator ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0x8 # A list of bitflags iex&gt; [0x8, 0x4] ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0xC # A list of names iex&gt; [:administrator, :ban_members] ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0xC # A mixture of both iex&gt; [:manage_roles, 0x400, 0x800, :add_reactions] ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0x10000C40 # An empty list iex&gt; [] ...&gt; |&gt; Crux.Structs.Permissions.resolve() 0x0"},{"ref":"Crux.Structs.Permissions.html#to_list/1","title":"Crux.Structs.Permissions.to_list/1","type":"function","doc":"Serializes permissions into a list of set name/0s. Examples iex&gt; 0x30 ...&gt; |&gt; Crux.Structs.Permissions.to_list() [:manage_guild, :manage_channels]"},{"ref":"Crux.Structs.Permissions.html#to_map/1","title":"Crux.Structs.Permissions.to_map/1","type":"function","doc":"Serializes permissions into a map keyed by name/0 with a boolean indicating whether the permission is set."},{"ref":"Crux.Structs.Permissions.html#t:name/0","title":"Crux.Structs.Permissions.name/0","type":"type","doc":"Union type of all valid permission name atoms."},{"ref":"Crux.Structs.Permissions.html#t:resolvable/0","title":"Crux.Structs.Permissions.resolvable/0","type":"type","doc":"All valid types which can be directly resolved into a permissions bitfield."},{"ref":"Crux.Structs.Permissions.html#t:t/0","title":"Crux.Structs.Permissions.t/0","type":"type","doc":"Represents a Crux.Structs.Permissions.t/0. :bitfield: The raw bitfield of permission flags."},{"ref":"Crux.Structs.Presence.html","title":"Crux.Structs.Presence","type":"module","doc":"Represents a Discord Presence Object. Differences opposed to the Discord API Object: :user is just the user id"},{"ref":"Crux.Structs.Presence.html#create/1","title":"Crux.Structs.Presence.create/1","type":"function","doc":"Creates a Crux.Structs.Presence.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Presence.html#resolve_id/1","title":"Crux.Structs.Presence.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Presence.t/0 Automatically invoked by Crux.Structs.resolve_id/2 For examples see Crux.Structs.User.resolve_id/1"},{"ref":"Crux.Structs.Presence.html#t:id_resolvable/0","title":"Crux.Structs.Presence.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a user id."},{"ref":"Crux.Structs.Presence.html#t:t/0","title":"Crux.Structs.Presence.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Reaction.html","title":"Crux.Structs.Reaction","type":"module","doc":"Represents a Discord Reaction Object."},{"ref":"Crux.Structs.Reaction.html#create/1","title":"Crux.Structs.Reaction.create/1","type":"function","doc":"Creates a Crux.Structs.Presence.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Reaction.html#resolve_id/1","title":"Crux.Structs.Reaction.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Reaction.t/0. Automatically invoked by Crux.Structs.resolve_id/2. iex&gt; %Crux.Structs.Reaction{emoji: %Crux.Structs.Emoji{id: 618731477143912448}} ...&gt; |&gt; Crux.Structs.Reaction.resolve_id() 618731477143912448 iex&gt; %Crux.Structs.Emoji{id: 618731477143912448} ...&gt; |&gt; Crux.Structs.Reaction.resolve_id() 618731477143912448 iex&gt; 618731477143912448 ...&gt; |&gt; Crux.Structs.Reaction.resolve_id() 618731477143912448 iex&gt; &quot;618731477143912448&quot; ...&gt; |&gt; Crux.Structs.Reaction.resolve_id() 618731477143912448"},{"ref":"Crux.Structs.Reaction.html#t:id_resolvable/0","title":"Crux.Structs.Reaction.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a reaction / emoji id."},{"ref":"Crux.Structs.Reaction.html#t:t/0","title":"Crux.Structs.Reaction.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Role.html","title":"Crux.Structs.Role","type":"module","doc":"Represents a Discord Role Object."},{"ref":"Crux.Structs.Role.html#create/1","title":"Crux.Structs.Role.create/1","type":"function","doc":"Creates a Crux.Structs.Role.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Role.html#resolve_position/1","title":"Crux.Structs.Role.resolve_position/1","type":"function","doc":"Resolves a position_resolvable/0 into a role position. Examples iex&gt; {%Crux.Structs.Role{id: 373405430589816834}, 5} ...&gt; |&gt; Crux.Structs.Role.resolve_position() %{id: 373405430589816834, position: 5} iex&gt; %{id: 373405430589816834, position: 5} ...&gt; |&gt; Crux.Structs.Role.resolve_position() %{id: 373405430589816834, position: 5} iex&gt; %{role: %Crux.Structs.Role{id: 373405430589816834}, position: 5} ...&gt; |&gt; Crux.Structs.Role.resolve_position() %{id: 373405430589816834, position: 5} iex&gt; {373405430589816834, 5} ...&gt; |&gt; Crux.Structs.Role.resolve_position() %{id: 373405430589816834, position: 5} iex&gt; {nil, 5} ...&gt; |&gt; Crux.Structs.Role.resolve_position() nil"},{"ref":"Crux.Structs.Role.html#to_mention/1","title":"Crux.Structs.Role.to_mention/1","type":"function","doc":"Converts a Crux.Structs.Role.t/0 into its discord mention format. Example iex&gt; %Crux.Structs.Role{id: 376146940762783746} ...&gt; |&gt; Crux.Structs.Role.to_mention() &quot;&lt;@&amp;376146940762783746&gt;&quot;"},{"ref":"Crux.Structs.Role.html#t:id_resolvable/0","title":"Crux.Structs.Role.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a role id."},{"ref":"Crux.Structs.Role.html#t:position_resolvable/0","title":"Crux.Structs.Role.position_resolvable/0","type":"type","doc":"All available types that can be resolved into a role position."},{"ref":"Crux.Structs.Role.html#t:t/0","title":"Crux.Structs.Role.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Snowflake.html","title":"Crux.Structs.Snowflake","type":"module","doc":"Custom non discord api struct to help with working with Discord&#39;s snowflakes. For more information see Discord Docs."},{"ref":"Crux.Structs.Snowflake.html#construct/1","title":"Crux.Structs.Snowflake.construct/1","type":"function","doc":"Constructs a t/0 from its Crux.Structs.Snowflake.Parts.t/0 or a keyword of its fields. iex&gt; %Crux.Structs.Snowflake.Parts{increment: 0, process_id: 0, timestamp: 1472128634889, worker_id: 1} ...&gt; |&gt; Crux.Structs.Snowflake.construct() 218348062828003328 iex&gt; Crux.Structs.Snowflake.construct(increment: 1, timestamp: 1451106635493) 130175406673231873 iex&gt; Crux.Structs.Snowflake.construct(timestamp: Crux.Structs.Snowflake.discord_epoch()) 0"},{"ref":"Crux.Structs.Snowflake.html#deconstruct/1","title":"Crux.Structs.Snowflake.deconstruct/1","type":"function","doc":"Deconstructs a t/0 to its Crux.Structs.Snowflake.Parts.t/0. iex&gt; Crux.Structs.Snowflake.deconstruct(218348062828003328) %Crux.Structs.Snowflake.Parts{ increment: 0, process_id: 0, timestamp: 1472128634889, worker_id: 1 }"},{"ref":"Crux.Structs.Snowflake.html#discord_epoch/0","title":"Crux.Structs.Snowflake.discord_epoch/0","type":"function","doc":"The discord epoch, the first second of 2015 or 1420070400000. iex&gt; Crux.Structs.Snowflake.discord_epoch() 1_420_070_400_000"},{"ref":"Crux.Structs.Snowflake.html#from_integer/1","title":"Crux.Structs.Snowflake.from_integer/1","type":"function","doc":"Deconstructs a t/0 to its Crux.Structs.Snowflake.Parts.t/0."},{"ref":"Crux.Structs.Snowflake.html#is_snowflake/1","title":"Crux.Structs.Snowflake.is_snowflake/1","type":"macro","doc":"Returns true if term is a t/0; otherwise returns false.."},{"ref":"Crux.Structs.Snowflake.html#parse/1","title":"Crux.Structs.Snowflake.parse/1","type":"function","doc":"Converts a String.t/0 to a t/0 while allowing t/0 to pass through. Returns :error if the provided string is not a t/0. iex&gt; Crux.Structs.Snowflake.parse(&quot;invalid&quot;) :error iex&gt; Crux.Structs.Snowflake.parse(218348062828003328) 218348062828003328 # Fallbacks iex&gt; Crux.Structs.Snowflake.parse(&quot;218348062828003328&quot;) 218348062828003328"},{"ref":"Crux.Structs.Snowflake.html#to_integer/1","title":"Crux.Structs.Snowflake.to_integer/1","type":"function","doc":"Constructs a t/0 from its Crux.Structs.Snowflake.Parts.t/0."},{"ref":"Crux.Structs.Snowflake.html#to_snowflake/1","title":"Crux.Structs.Snowflake.to_snowflake/1","type":"function","doc":"Converts a String.t/0 to a t/0 while allowing t/0 and nil to pass through. Raises an ArgumentError if the provided string is not an integer. iex&gt; Crux.Structs.Snowflake.to_snowflake(218348062828003328) 218348062828003328 # Fallbacks iex&gt; Crux.Structs.Snowflake.to_snowflake(&quot;218348062828003328&quot;) 218348062828003328 iex&gt; Crux.Structs.Snowflake.to_snowflake(nil) nil"},{"ref":"Crux.Structs.Snowflake.html#t:resolvable/0","title":"Crux.Structs.Snowflake.resolvable/0","type":"type","doc":"All valid types that can be resolved into a t/0."},{"ref":"Crux.Structs.Snowflake.html#t:t/0","title":"Crux.Structs.Snowflake.t/0","type":"type","doc":"A discord snowflake, an unsigned 64 bit integer."},{"ref":"Crux.Structs.Snowflake.Parts.html","title":"Crux.Structs.Snowflake.Parts","type":"module","doc":"Custom non discord api struct representing a deconstructed Discord snowflake. Structure of the Parts FieldBitsNumber of BitsDescription Timestamp63 to 2242 bitsMilliseconds since Discord Epoch (1420070400000) Internal Worker ID21 to 175 bits Internal Process ID16 to 125 bits Increment11 to 012 bitsFor every ID that is generated on that process, this number is incremented For more information see Discord Docs."},{"ref":"Crux.Structs.Snowflake.Parts.html#t:t/0","title":"Crux.Structs.Snowflake.Parts.t/0","type":"type","doc":"The parts of a Crux.Structs.Snowflake.t/0."},{"ref":"Crux.Structs.User.html","title":"Crux.Structs.User","type":"module","doc":"Represents a Discord User Object"},{"ref":"Crux.Structs.User.html#create/1","title":"Crux.Structs.User.create/1","type":"function","doc":"Creates a Crux.Structs.User.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.User.html#resolve_id/1","title":"Crux.Structs.User.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.Guild.t/0. Automatically invoked by Crux.Structs.resolve_id/2. iex&gt; %Crux.Structs.User{id: 218348062828003328} ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; %Crux.Structs.Member{user: 218348062828003328} ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; %Crux.Structs.Message{author: %Crux.Structs.User{id: 218348062828003328}} ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; %Crux.Structs.Presence{user: 218348062828003328} ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; %Crux.Structs.VoiceState{user_id: 218348062828003328} ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; 218348062828003328 ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328 iex&gt; &quot;218348062828003328&quot; ...&gt; |&gt; Crux.Structs.User.resolve_id() 218348062828003328"},{"ref":"Crux.Structs.User.html#to_mention/1","title":"Crux.Structs.User.to_mention/1","type":"function","doc":"Converts a Crux.Structs.User.t/0 into its discord mention format. iex&gt; %Crux.Structs.User{id: 218348062828003328} ...&gt; |&gt; Crux.Structs.User.to_mention() &quot;&lt;@218348062828003328&gt;&quot;"},{"ref":"Crux.Structs.User.html#t:id_resolvable/0","title":"Crux.Structs.User.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a user id."},{"ref":"Crux.Structs.User.html#t:t/0","title":"Crux.Structs.User.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Util.html","title":"Crux.Structs.Util","type":"module","doc":"Collection of util functions."},{"ref":"Crux.Structs.Util.html#atomify/1","title":"Crux.Structs.Util.atomify/1","type":"function","doc":"Atomifies all keys in a passed list or map to avoid the mess of mixed string and atom keys the gateway sends. Examples # A map iex&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;} ...&gt; |&gt; Crux.Structs.Util.atomify() %{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: &quot;218348062828003328&quot;, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;} # A list iex&gt; [ ...&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; %{&quot;username&quot; =&gt; &quot;Drahcirius&quot;, &quot;discriminator&quot; =&gt; &quot;1336&quot;, &quot;id&quot; =&gt; &quot;130175406673231873&quot;, &quot;avatar&quot; =&gt; &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ...&gt; ] ...&gt; |&gt; Crux.Structs.Util.atomify() [ %{username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: &quot;218348062828003328&quot;, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, %{username: &quot;Drahcirius&quot;, discriminator: &quot;1336&quot;, id: &quot;130175406673231873&quot;, avatar: &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ] # A nested map iex&gt; %{&quot;foo&quot; =&gt; &quot;bar&quot;, &quot;bar&quot; =&gt; %{&quot;baz&quot; =&gt; &quot;foo&quot;}} ...&gt; |&gt; Crux.Structs.Util.atomify() %{foo: &quot;bar&quot;, bar: %{baz: &quot;foo&quot;}} # A nested list iex&gt; [[%{&quot;foo&quot; =&gt; &quot;bar&quot;}], %{&quot;bar&quot; =&gt; &quot;foo&quot;}] ...&gt; |&gt; Crux.Structs.Util.atomify() [[%{foo: &quot;bar&quot;}], %{bar: &quot;foo&quot;}] # A struct iex&gt; %Crux.Structs.Overwrite{id: 448394877194076161, type: &quot;role&quot;, allow: 0, deny: 0} ...&gt; |&gt; Crux.Structs.Util.atomify() %{id: 448394877194076161, type: &quot;role&quot;, allow: 0, deny: 0}"},{"ref":"Crux.Structs.Util.html#id_to_int/1","title":"Crux.Structs.Util.id_to_int/1","type":"function","doc":"Converts a string, likely Discord snowflake, to not negative integer Examples # A string iex&gt; &quot;218348062828003328&quot; |&gt; Crux.Structs.Util.id_to_int() 218348062828003328 # Already a number iex&gt; 218348062828003328 |&gt; Crux.Structs.Util.id_to_int() 218348062828003328 # Fallback iex&gt; nil |&gt; Crux.Structs.Util.id_to_int() nil"},{"ref":"Crux.Structs.Util.html#map_to_id/1","title":"Crux.Structs.Util.map_to_id/1","type":"function","doc":"Returns a function converting a passed map to an id, using the specified key as key. Examples # Id is already a number iex&gt; Crux.Structs.Util.map_to_id(:foo).(%{foo: 123}) 123 # Id is a string iex&gt; Crux.Structs.Util.map_to_id(:foo).(%{foo: &quot;123&quot;}) 123 # No id exists iex&gt; Crux.Structs.Util.map_to_id(:foo).(%{&quot;foo&quot; =&gt; &quot;123&quot;}) nil # Example using [`Enum.map/2`](https://hexdocs.pm/elixir/Enum.html#map/2) iex&gt; [ ...&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; %{&quot;username&quot; =&gt; &quot;Drahcirius&quot;, &quot;discriminator&quot; =&gt; &quot;1336&quot;, &quot;id&quot; =&gt; &quot;130175406673231873&quot;, &quot;avatar&quot; =&gt; &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ...&gt; ] ...&gt; |&gt; Enum.map(Crux.Structs.Util.map_to_id(&quot;id&quot;)) [218348062828003328, 130175406673231873]"},{"ref":"Crux.Structs.Util.html#modulesince/1","title":"Crux.Structs.Util.modulesince/1","type":"macro","doc":""},{"ref":"Crux.Structs.Util.html#raw_data_to_map/3","title":"Crux.Structs.Util.raw_data_to_map/3","type":"function","doc":"Converts a list of raw api data to structs keyed under the passed key. Examples iex&gt; [ ...&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; %{&quot;username&quot; =&gt; &quot;Drahcirius&quot;, &quot;discriminator&quot; =&gt; &quot;1336&quot;, &quot;id&quot; =&gt; &quot;130175406673231873&quot;, &quot;avatar&quot; =&gt; &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ...&gt; ] ...&gt; |&gt; Crux.Structs.Util.raw_data_to_map(Crux.Structs.User) %{ 130175406673231873 =&gt; %Crux.Structs.User{ username: &quot;Drahcirius&quot;, discriminator: &quot;1336&quot;, id: 130175406673231873, avatar: &quot;c896aebec82c90f590b08cfebcdc4e3b&quot; }, 218348062828003328 =&gt; %Crux.Structs.User{ username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot; } } iex&gt; [ ...&gt; %{&quot;username&quot; =&gt; &quot;space&quot;, &quot;discriminator&quot; =&gt; &quot;0001&quot;, &quot;id&quot; =&gt; &quot;218348062828003328&quot;, &quot;avatar&quot; =&gt; &quot;46a356e237350bf8b8dfde15667dfc4&quot;}, ...&gt; %{&quot;username&quot; =&gt; &quot;Drahcirius&quot;, &quot;discriminator&quot; =&gt; &quot;1336&quot;, &quot;id&quot; =&gt; &quot;130175406673231873&quot;, &quot;avatar&quot; =&gt; &quot;c896aebec82c90f590b08cfebcdc4e3b&quot;} ...&gt; ] ...&gt; |&gt; Crux.Structs.Util.raw_data_to_map(Crux.Structs.User, :username) %{ &quot;Drahcirius&quot; =&gt; %Crux.Structs.User{ username: &quot;Drahcirius&quot;, discriminator: &quot;1336&quot;, id: 130175406673231873, avatar: &quot;c896aebec82c90f590b08cfebcdc4e3b&quot; }, &quot;space&quot; =&gt; %Crux.Structs.User{ username: &quot;space&quot;, discriminator: &quot;0001&quot;, id: 218348062828003328, avatar: &quot;46a356e237350bf8b8dfde15667dfc4&quot; } }"},{"ref":"Crux.Structs.Util.html#since/1","title":"Crux.Structs.Util.since/1","type":"macro","doc":""},{"ref":"Crux.Structs.Util.html#string_to_atom/1","title":"Crux.Structs.Util.string_to_atom/1","type":"function","doc":"Converts a string to an atom. Returns an already converted atom as is instead of raising Examples # A string iex&gt; &quot;id&quot; |&gt; Crux.Structs.Util.string_to_atom() :id # Already an atom iex&gt; :id |&gt; Crux.Structs.Util.string_to_atom() :id"},{"ref":"Crux.Structs.Util.html#typesince/1","title":"Crux.Structs.Util.typesince/1","type":"macro","doc":""},{"ref":"Crux.Structs.VoiceState.html","title":"Crux.Structs.VoiceState","type":"module","doc":"Represents a Discord Voice State Object"},{"ref":"Crux.Structs.VoiceState.html#create/1","title":"Crux.Structs.VoiceState.create/1","type":"function","doc":"Creates a Crux.Structs.VoiceState.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.VoiceState.html#resolve_id/1","title":"Crux.Structs.VoiceState.resolve_id/1","type":"function","doc":"Resolves the id of a Crux.Structs.VoiceState.t/0. Automatically invoked by Crux.Structs.resolve_id/2. For examples see Crux.Structs.User.resolve_id/1."},{"ref":"Crux.Structs.VoiceState.html#t:id_resolvable/0","title":"Crux.Structs.VoiceState.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a user id."},{"ref":"Crux.Structs.VoiceState.html#t:t/0","title":"Crux.Structs.VoiceState.t/0","type":"type","doc":""},{"ref":"Crux.Structs.Webhook.html","title":"Crux.Structs.Webhook","type":"module","doc":"Represents a Discord Webhook Object Differences opposed to the Discord API Object: :user is just the user id"},{"ref":"Crux.Structs.Webhook.html#create/1","title":"Crux.Structs.Webhook.create/1","type":"function","doc":"Creates a Crux.Structs.Webhook.t/0 struct from raw data. Automatically invoked by Crux.Structs.create/2."},{"ref":"Crux.Structs.Webhook.html#to_mention/1","title":"Crux.Structs.Webhook.to_mention/1","type":"function","doc":"Converts a Crux.Structs.Webhook.t/0 into its discord mention format. Although the discord client does not autocomplete it for you, mentioning one still works. iex&gt; %Crux.Structs.Webhook{id: 218348062828003328} ...&gt; |&gt; Crux.Structs.Webhook.to_mention() &quot;&lt;@218348062828003328&gt;&quot;"},{"ref":"Crux.Structs.Webhook.html#t:id_resolvable/0","title":"Crux.Structs.Webhook.id_resolvable/0","type":"type","doc":"All available types that can be resolved into a webhook id."},{"ref":"Crux.Structs.Webhook.html#t:t/0","title":"Crux.Structs.Webhook.t/0","type":"type","doc":""}]